@@ -4,7 +4,7 @@ package Test::Class::Moose;
 
 use 5.10.0;
 
-our $VERSION = '0.76';
+our $VERSION = '0.77';
 
 use Moose 2.0000;
 use Carp;
@@ -170,41 +170,6 @@ sub import {
     }
 }
 
-# XXX - this is only necessary for backwards compatibility, where people call
-# Test::Class::Moose->new(...)->runtests() instead of
-# Test::Class::Moose::Runner->new(...)->runtests()
-my %config_attrs = map { $_->init_arg => 1 }
-  Test::Class::Moose::Config->meta->get_all_attributes;
-around 'BUILDARGS' => sub {
-    my $orig  = shift;
-    my $class = shift;
-
-    my $p = $class->$orig(@_);
-
-    my %config_p
-      = map { $_ => delete $p->{$_} } grep { $config_attrs{$_} } keys %{$p};
-    $p->{_config_p} = \%config_p;
-
-    return $p;
-};
-
-# XXX - also for backwards compat
-sub runtests {
-    my $self = shift;
-
-    Test::Class::Moose::Deprecated::deprecated(
-        message =>
-          'Calling runtests() on a Test::Class::Moose object is deprecated.'
-          . ' Use Test::Class::Moose::Runner instead.',
-        feature => 'Test::Class::Moose->runtests',
-    );
-
-    require Test::Class::Moose::Runner;
-    my $runner = Test::Class::Moose::Runner->new( $self->_config_p );
-
-    return $runner->runtests();
-}
-
 sub _tcm_make_test_class_instances {
     my $test_class = shift;
 
@@ -262,7 +227,7 @@ Test::Class::Moose - Serious testing for serious Perl
 
 =head1 VERSION
 
-version 0.76
+version 0.77
 
 =head1 SYNOPSIS
 
@@ -927,17 +892,87 @@ Or even shorter:
 If you would like L<Test::Class::Moose> to take care of loading your classes
 for you, see L<Test::Class::Moose::Role::AutoUse> in this distribution.
 
-=head1 DEPRECATIONS
+=head1 DEPRECATIONS AND BACKWARDS INCOMPATIBILITIES
+
+=head2 Version 0.77
+
+=over 4
+
+=item *
+
+The passing of the report object as an argument to test methods and test
+control methods is now deprecated. You can get the report from the test class
+object itself via the C<< $test->test_report >> method.
+
+=item *
+
+The C<< Test::Class::Moose->runtests >> method has been removed. Use
+L<Test::Class::Moose::Runner> to run your test classes.
+
+=item *
+
+The C<Test::Class::Moose::Role::Paralllel> role has been removed. This has not
+done anything except issue a warning since version 0.55.
+
+=back
+
+=head2 Version 0.75
+
+=over 4
+
+=item *
+
+The C<test_teardown method> is no longer run when a test is skipped unless
+C<run_control_methods_on_skip> returns a true value. The C<test_teardown
+method> was never intended to be run unconditionally.
+
+=item *
+
+Parallel testing now parallelizes test classes rather than individual test
+instances. This is only relevant if your test suite contains parameterized
+test classes. This is slightly less efficient, but made the internal test
+running code much simpler and made it possible to fix reporting for parallel
+test runs.
+
+=item *
+
+The L<Test::Class::Moose::Config> C<builder> method has been removed.
+
+=item *
+
+The L<Test::Class::Moose::Runner> C<builder> method has been removed.
+
+=back
 
 =head2 Version 0.67
 
 =over 4
 
-=item * The L<Test::Class::Moose::Report> class's C<test_classes> method is un-deprecated
+=item * The L<Test::Class::Moose::Report> class's C<all_test_classes> method is un-deprecated
 
 This method now returns a list of L<Test::Class::Moose::Report::Class>
 objects. A class report contains one or more instance reports.
 
+=item *
+
+Removed the L<Test::Class::Moose::Report::Instance>'s error
+attribute. Contrary to the documentation, this attribute was never populated.
+
+=item *
+
+Renamed the L<Test::Class::Moose::Report::Method> C<instance_report> method to
+C<instance>. This is a better match for other report-related methods, which
+don't include a "_report" suffix.
+
+=item *
+
+Removed the long-deprecated C<tests_run> methods from
+L<Test::Class::Moose::Report> and L<Test::Class::Moose::Report::Method>.
+
+=item *
+
+Removed the long-deprecated TCM::Report::Method->add_to_plan method.
+
 =back
 
 =head2 Version 0.55
@@ -1038,7 +1073,7 @@ You write this:
 
 =back
 
-=head1 SUPPORT
+=head1 MORE INFO
 
 You can find documentation for this module with the perldoc command.
 
@@ -1048,14 +1083,6 @@ You can also look for information at:
 
 =over 4
 
-=item * GitHub Issues (report bugs here)
-
-L<https://github.com/test-class-moose/test-class-moose/issues>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Test-Class-Moose>
-
 =item * CPAN Ratings
 
 L<http://cpanratings.perl.org/d/Test-Class-Moose>
@@ -1091,15 +1118,9 @@ L<Test::Class> + L<Test::Most>.
 
 =back
 
-=head1 BUGS
+=head1 SUPPORT
 
-Please report any bugs or feature requests to C<bug-test-class-moose at rt.cpan.org>,
-or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Test-Class-Moose>.  I will be
-notified, and then you'll automatically be notified of progress on your bug as
-I make changes.
-
-bugs may be submitted through L<https://github.com/test-class-moose/test-class-moose/issues>.
+Bugs may be submitted through L<https://github.com/test-class-moose/test-class-moose/issues>.
 
 I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
 
@@ -1205,7 +1226,7 @@ Udo Oji <Velti@signor.com>
 
 =back
 
-=head1 COPYRIGHT AND LICENCE
+=head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2012 - 2016 by Curtis "Ovid" Poe.
 
