@@ -4,7 +4,7 @@ package Test::Class::Moose::Config;
 
 use 5.10.0;
 
-our $VERSION = '0.76';
+our $VERSION = '0.77';
 
 use Moose;
 use Moose::Util::TypeConstraints;
@@ -119,7 +119,7 @@ Test::Class::Moose::Config - Configuration information for Test::Class::Moose
 
 =head1 VERSION
 
-version 0.76
+version 0.77
 
 =head1 SYNOPSIS
 
@@ -211,43 +211,7 @@ testing. You probably won't need it.
 
 =head1 SUPPORT
 
-You can find documentation for this module with the perldoc command.
-
-    perldoc Test::Class::Moose
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker (report bugs here)
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Test-Class-Moose>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Test-Class-Moose>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Test-Class-Moose>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Test-Class-Moose/>
-
-=back
-
-=head1 ACKNOWLEDGEMENTS
-
-=head1 BUGS
-
-Please report any bugs or feature requests to C<bug-test-class-moose at rt.cpan.org>,
-or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Test-Class-Moose>.  I will be
-notified, and then you'll automatically be notified of progress on your bug as
-I make changes.
-
-bugs may be submitted through L<https://github.com/test-class-moose/test-class-moose/issues>.
+Bugs may be submitted through L<https://github.com/test-class-moose/test-class-moose/issues>.
 
 I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
 
@@ -265,7 +229,7 @@ Dave Rolsky <autarch@urth.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENCE
+=head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2012 - 2016 by Curtis "Ovid" Poe.
 
